==> hive-apache-jdbc-0.13.1-9-sources.jar: io/trino/hive/jdbc/$internal/org/apache/hadoop/hive/io/HiveIOExceptionNextHandleResult.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.trino.hive.jdbc.$internal.org.apache.hadoop.hive.io;

/**
 * A container to store handling results for exceptions produced in record
 * reader's next(). It basically contains 2 fields, one is to store if it is
 * handled or not, another field to store the result.
 */
public class HiveIOExceptionNextHandleResult {

  // this exception has been handled
  private boolean handled;

  //the handling results
  private boolean handleResult;

  public boolean getHandled() {
    return handled;
  }

  public void setHandled(boolean handled) {
    this.handled = handled;
  }

  public boolean getHandleResult() {
    return handleResult;
  }

  public void setHandleResult(boolean handleResult) {
    this.handleResult = handleResult;
  }

  public void clear() {
    handled = false;
    handleResult = false;
  }

}

==> hive-apache-jdbc-0.13.1-10-sources.jar: io/trino/hive/jdbc/$internal/org/apache/hadoop/hive/io/HiveIOExceptionNextHandleResult.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.trino.hive.jdbc.\$internal.org.apache.hadoop.hive.io;

/**
 * A container to store handling results for exceptions produced in record
 * reader's next(). It basically contains 2 fields, one is to store if it is
 * handled or not, another field to store the result.
 */
public class HiveIOExceptionNextHandleResult {

  // this exception has been handled
  private boolean handled;

  //the handling results
  private boolean handleResult;

  public boolean getHandled() {
    return handled;
  }

  public void setHandled(boolean handled) {
    this.handled = handled;
  }

  public boolean getHandleResult() {
    return handleResult;
  }

  public void setHandleResult(boolean handleResult) {
    this.handleResult = handleResult;
  }

  public void clear() {
    handled = false;
    handleResult = false;
  }

}
